"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HTTPError = exports.makeCatcher = void 0;
function AsyncWrapper(fn) {
    return function (req, res, next) {
        fn(req, res, next).catch((err) => {
            next(new HTTPError(err, req));
        });
    };
}
exports.default = AsyncWrapper;
function makeCatcher(Logger = false) {
    return function (err, _req, res, _next) {
        if (Logger)
            Logger.error(err.error);
        res.status(err.status ?? 404);
        if (!res.headersSent) {
            res.json({
                message: err.message ?? 'Not Found',
                error: process.env.NODE_ENV === 'production'
                    ? !err
                        ? {}
                        : err
                    : null,
            });
        }
    };
}
exports.makeCatcher = makeCatcher;
class HTTPError extends Error {
    constructor(err, req, status = 500) {
        super(err.message);
        this.name = err.name;
        this.status = status;
        this.method = req.method;
        this.path = req.path;
        this.error = err;
    }
}
exports.HTTPError = HTTPError;
//# sourceMappingURL=index.js.map